<?php

namespace Larajobs\Company\Policies;

use Litepie\User\Contracts\UserPolicy;
use Larajobs\Company\Models\Employer;

class EmployerPolicy
{

    /**
     * Determine if the given user can view the employer.
     *
     * @param UserPolicy $user
     * @param Employer $employer
     *
     * @return bool
     */
    public function view(UserPolicy $user, Employer $employer)
    {
        if ($user->canDo('company.employer.view') && $user->isAdmin()) {
            return true;
        }

        return $employer->user_id == user_id() && $employer->user_type == user_type();
    }

    /**
     * Determine if the given user can create a employer.
     *
     * @param UserPolicy $user
     * @param Employer $employer
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('company.employer.create');
    }

    /**
     * Determine if the given user can update the given employer.
     *
     * @param UserPolicy $user
     * @param Employer $employer
     *
     * @return bool
     */
    public function update(UserPolicy $user, Employer $employer)
    {
        if ($user->canDo('company.employer.edit') && $user->isAdmin()) {
            return true;
        }

        return $employer->user_id == user_id() && $employer->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given employer.
     *
     * @param UserPolicy $user
     * @param Employer $employer
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Employer $employer)
    {
        return $employer->user_id == user_id() && $employer->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given employer.
     *
     * @param UserPolicy $user
     * @param Employer $employer
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Employer $employer)
    {
        if ($user->canDo('company.employer.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given employer.
     *
     * @param UserPolicy $user
     * @param Employer $employer
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Employer $employer)
    {
        if ($user->canDo('company.employer.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
